# Generated by Django 2.1.3 on 2018-12-06 12:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('acmin', '0002_auto_20181206_1111'),
    ]

    operations = [
        migrations.AddField(
            model_name='field',
            name='editable',
            field=models.BooleanField(default=True, verbose_name='可编辑'),
        ),
        migrations.AddField(
            model_name='groupfield',
            name='editable',
            field=models.BooleanField(default=True, verbose_name='可编辑'),
        ),
        migrations.AddField(
            model_name='userfield',
            name='editable',
            field=models.BooleanField(default=True, verbose_name='可编辑'),
        ),
    ]
