# Generated by Django 2.1.3 on 2018-12-06 11:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('acmin', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='field',
            name='blank',
        ),
        migrations.RemoveField(
            model_name='groupfield',
            name='blank',
        ),
        migrations.RemoveField(
            model_name='userfield',
            name='blank',
        ),
        migrations.AddField(
            model_name='field',
            name='default',
            field=models.CharField(blank=True, max_length=500, null=True, verbose_name='默认值'),
        ),
        migrations.AddField(
            model_name='field',
            name='nullable',
            field=models.BooleanField(default=False, verbose_name='可以为空'),
        ),
        migrations.AddField(
            model_name='field',
            name='unique',
            field=models.BooleanField(default=False, verbose_name='是否唯一性'),
        ),
        migrations.AddField(
            model_name='groupfield',
            name='default',
            field=models.CharField(blank=True, max_length=500, null=True, verbose_name='默认值'),
        ),
        migrations.AddField(
            model_name='groupfield',
            name='nullable',
            field=models.BooleanField(default=False, verbose_name='可以为空'),
        ),
        migrations.AddField(
            model_name='groupfield',
            name='unique',
            field=models.BooleanField(default=False, verbose_name='是否唯一性'),
        ),
        migrations.AddField(
            model_name='userfield',
            name='default',
            field=models.CharField(blank=True, max_length=500, null=True, verbose_name='默认值'),
        ),
        migrations.AddField(
            model_name='userfield',
            name='nullable',
            field=models.BooleanField(default=False, verbose_name='可以为空'),
        ),
        migrations.AddField(
            model_name='userfield',
            name='unique',
            field=models.BooleanField(default=False, verbose_name='是否唯一性'),
        ),
    ]
