# Generated by Django 2.1.4 on 2018-12-26 15:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('acmin', '0006_auto_20181208_0840'),
    ]

    operations = [
        migrations.AddField(
            model_name='field',
            name='data_type',
            field=models.CharField(max_length=10, null=True, verbose_name='数据类型'),
        ),
        migrations.AddField(
            model_name='field',
            name='help_text',
            field=models.TextField(null=True, verbose_name='帮助文本'),
        ),
        migrations.AddField(
            model_name='field',
            name='max_length',
            field=models.IntegerField(null=True, verbose_name='最大长度'),
        ),
        migrations.AddField(
            model_name='field',
            name='serialize',
            field=models.BooleanField(null=True, verbose_name='可序列化'),
        ),
    ]
