# Generated by Django 2.1.3 on 2019-01-07 14:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('acmin', '0011_auto_20190103_1552'),
    ]

    operations = [
        migrations.AlterField(
            model_name='groupfilter',
            name='value_type',
            field=models.SmallIntegerField(choices=[(10, '固定值'), (5, '请求属性')], verbose_name='值类型'),
        ),
        migrations.AlterField(
            model_name='userfilter',
            name='value_type',
            field=models.SmallIntegerField(choices=[(10, '固定值'), (5, '请求属性')], verbose_name='值类型'),
        ),
    ]
