# Generated by Django 2.1.3 on 2019-01-03 15:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('acmin', '0010_auto_20190103_1520'),
    ]

    operations = [
        migrations.AddField(
            model_name='field',
            name='filterable',
            field=models.BooleanField(default=True, verbose_name='可过滤'),
        ),
        migrations.AddField(
            model_name='groupfield',
            name='filterable',
            field=models.BooleanField(default=True, verbose_name='可过滤'),
        ),
        migrations.AddField(
            model_name='userfield',
            name='filterable',
            field=models.BooleanField(default=True, verbose_name='可过滤'),
        ),
    ]
