# Generated by Django 2.1.3 on 2019-01-03 14:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('acmin', '0008_auto_20181226_1547'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='groupfield',
            name='max_length',
        ),
        migrations.RemoveField(
            model_name='groupfield',
            name='serialize',
        ),
        migrations.RemoveField(
            model_name='userfield',
            name='max_length',
        ),
        migrations.RemoveField(
            model_name='userfield',
            name='serialize',
        ),
    ]
