# Generated by Django 2.1.3 on 2019-01-03 15:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('acmin', '0009_auto_20190103_1421'),
    ]

    operations = [
        migrations.CreateModel(
            name='Choice',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.CharField(max_length=100, verbose_name='值')),
                ('title', models.CharField(max_length=100, verbose_name='标题')),
                ('field', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='acmin.Field', verbose_name='默认字段')),
            ],
            options={
                'verbose_name': '选项',
                'verbose_name_plural': '选项',
                'ordering': ['field', 'id'],
            },
        ),
        migrations.AlterUniqueTogether(
            name='choice',
            unique_together={('field', 'value')},
        ),
    ]
